@@ -4,14 +4,14 @@
 import warnings
 
 from .base_utils import (AioQueue, DefaultDict, Dict, DictUnwrapper,
-                         DictWrapper, JSONEncoder, Queue, Singleton, awaitable,
-                         ceil, connect, floor, get_ip, int2ip, int2str, ip2int,
-                         pprint, str2int, to_bytes, to_str, tqdm, yaml_dump,
-                         yaml_load)
+                         DictWrapper, JSONEncoder, Queue, Singleton, Storage,
+                         awaitable, ceil, connect, floor, get_ip, int2ip,
+                         int2str, ip2int, pprint, str2int, to_bytes, to_str,
+                         tqdm, yaml_dump, yaml_load)
 from .cached_property import cached_property
 from .config_utils import Config
-from .crypto import (des_encrypt, des_decrypt, aes_encrypt, aes_decrypt,
-                     gen_rsa_key, rsa_encrypt, rsa_decrypt)
+from .crypto import (aes_decrypt, aes_encrypt, des_decrypt, des_encrypt,
+                     gen_rsa_key, rsa_decrypt, rsa_encrypt)
 from .db_utils import (AioMysql, AioRedis, Mongo, MongoClient, Motor,
                        MotorClient, Mysql, Redis, parse_uri)
 from .decorator import aioretry, retry, smart_decorator, synchronize, timeit
@@ -37,7 +37,7 @@ __all__ = [
     'get_ip', 'connect', 'ip2int', 'int2ip', 'int2str', 'str2int', 'patch_connection_pool', 'parse_uri',
     'des_encrypt', 'des_decrypt', 'aes_encrypt', 'aes_decrypt', 'gen_rsa_key', 'rsa_encrypt', 'rsa_decrypt',
     'Fire', 'Ip2Region', 'Singleton', 'JSONEncoder', 'Dict', 'DefaultDict', 'DictWrapper', 'DictUnwrapper',
-    'Email', 'AioEmail', 'Queue', 'AioQueue', 'Config', 'Logger', 'WatchedFileHandler',
+    'Email', 'AioEmail', 'Queue', 'AioQueue', 'Config', 'Logger', 'WatchedFileHandler', 'Storage',
     'Mongo', 'MongoClient', 'Redis', 'AioRedis', 'Motor', 'MotorClient', 'Mysql', 'AioMysql', 'Pika', 'AioPika',
     'Request', 'Response', 'Chrome'
 ]
