@@ -63,7 +63,7 @@ class Config(Dict):
         elif config.endswith('.json'):
             cfg.update(Dict(json.load(open(config))))
         elif config.endswith('.yaml') or config.endswith('.yml'):
-            cfg.update(Dict(yaml.load(open(config))))
+            cfg.update(Dict(yaml.load(open(config), Loader=yaml.FullLoader)))
         else:
             raise TypeError(f'{config} must be dict, ini, json or yaml')
 
